## ----setup, include=FALSE-----------------------------------------------------
knitr::opts_chunk$set(echo = FALSE, 
                      message = FALSE, 
                      warning = FALSE,
                      root.dir = here::here(), 
                      fig.path = here::here("figs/"), 
                      cache = TRUE,
                      fig.align = "center",
                      fig.height = 3,
                      fig.retina = 5,
                      out.width = "100%")


## ----external, include = FALSE, cache = FALSE---------------------------------
knitr::read_chunk(
  here::here("script.R")
)


## ----load-pkg-----------------------------------------------------------------


## ----tour-path, fig.cap="An illustration for demonstrating the frames in a tour path. Each square (frame) represents the projected data with a corresponding basis. Blue frames are returned by the projection pursuit optimisation and white frames are constructed between two blue frames by geodesic interpolation."----


## ----toy-search, fig.cap="A comparison of the searches by two optimisers: CRS (left) and SA (right) on a 2D projection problem of a six-variable dataset, \\code{boa6} using the holes index. Both optimisers reach the final basis with a similar index value, while it takes SA longer to find the final basis. In the earlier iterations, optimisers quickly find a better basis to proceed, while in the later iterations, most sampled bases fail to make an improvement on the index value, and a boxplot is used to summarise the distribution of the index values. There is no better basis found in the last iteration, 9 (left) and 15 (right), before reaching the maximum number of try and hence it is colored grey. The color scale is from the customised botanical palette in the **ferrn** package."----


## ----toy-interp, fig.cap = "An inspection of the index values as the optimisation progress for two optimisers: CRS (left) and SA (right). The holes index is optimised for a 2D projection problem on the six-variable dataset \\code{boa6}. Lines indicate the interpolation, and dots indicate new target bases generated by the optimisers. Interpolation in both optimisation is smooth, while SA is observed to first pass by some bases with higher index values before reaching the target bases in time 76-130."----


## ----toy-pca, out.width = "70%", fig.cap = "Search paths of CRS (green) and PD (brown) in the PCA-reduced basis space for 1D projection problem on the five-variable dataset, \\code{boa5} using holes index. The basis space, a 5D unit sphere, is projected onto a 2D circle by PCA. The black star represents the theoretical best basis the optimisers are aiming to find. All the bases in PD have been flipped for easier comparison of the final bases, and a grey dashed line has been annotated to indicate the symmetry of the two start bases."----


## ----toy-pca-animated, fig.cap = "Six frames selected from the animated version of the previous plot. With animation, the progression of the search paths from start to finish is better identified. CRS (green) finishes the optimisation quicker than PD (brown) since there is no further movement for CRS in the sixth frame. The full video of the animation can be found in the html version of the paper.", eval=knitr::is_latex_output()----


## ----toy-pca-animated-interactive, out.extra="class = 'gif'", fig.cap = "Animated version of Figure 4. With animation, the progression of the search paths from start to finish can better identified and CRS (green) finishes the optimisation quicker than PD (brown).", eval=knitr::is_html_output()----
#> NA


## ----toy-tour, fig.cap="Six frames selected from rotating the high-dimensional basis space, along with the same two search paths from Figure \\ref{fig:toy-pca} and \\ref{fig:toy-pca-animated}. The basis space in this example is a 5D unit sphere, on which points (grey) are randomly generated via the CRAN package geozoo. The full animation can be seen in the html version of the paper.", eval = knitr::is_latex_output()----


## ----toy-tour-interactive, out.extra="class = 'tour-gif'",fig.cap="Animating the two paths from Figure 4 and 5 in the full basis space. The full basis space in this example is a 5D unit sphere, on which points (grey) are randomly generated via the CRAN package geozoo.", eval = knitr::is_html_output()----
#> NA


## -----------------------------------------------------------------------------
holes_2d_geo_3var %>% get_best() %>% pull(basis) %>% .[[1]]


## -----------------------------------------------------------------------------
holes_2d_better_3var %>% get_best() %>% pull(basis) %>% .[[1]]


## ----toy-torus, fig.cap="Six frames selected from rotating the 2D basis space along with two search paths optimised by PD (brown) and CRS (green). The projection problem is a 2D projection with three variables using the holes index. The grey points are randomly generated 2D projection bases in the space, and it can be observed that these points form a torus. The full video of the animation can be found in the html version of the paper.", eval = knitr::is_latex_output()----


## ----toy-torus-interactive, out.extra="class = 'tour-gif'", fig.cap="Animation of rotating the 2D basis space along with two search paths optimised by PD (brown) and CRS (green). The projection problem is a 2D projection with three variables using the holes index. The grey points are randomly generated 2D projection bases in the space and it can be observed that these points form a torus.", eval = knitr::is_html_output()----
#> NA


## ----interruption, fig.cap = "Comparison of the interpolation before and after implementing the interruption for the 2D projection problem on \\code{boa6} data using holes index, optimised by CRS. On the left panel, the basis with a higher index value is found during the interpolation but not used. On the right panel, the interruption stops the interpolation at the basis with the highest index value for each iteration and results in a final basis with a higher index value, as shown on the right panel."----


## ----polish, fig.height= 5, fig.cap = "Comparison of the projected data before and after using polishing for a 2D projection problem on \\code{boa6} data using holes index. The top row shows the initial projected data and the final views after CRS and polish search, and the second row traces the index value. The clustering structure in the data is detected by CRS (top middle panel), but the polish step improves the index value and produces clearer boundaries of the clusters (top right panel), especially along the vertical axis. Note that the parameter \\code{max.tries} is set to 400 in this experiment for CRS to do its best. "----


## ----noisy-better-geo, fig.height = 5, fig.cap = "Comparison of the three optimisers in optimising $I^{nk}(n)$ index for a 1D projection problem on a five-variable dataset, \\code{boa5}. Both CRS and SA succeed in the optimisation, PD fails to optimise this non-smooth index. Further, SA takes  much longer than CRS to finish the optimisation, but finishes off closer to the theoretical best."----


## ----kol-result, fig.height = 4, fig.cap="Comparing 20 search paths in the PCA-projected basis space faceted by two optimisers: CRS and SA, and two search sizes: 0.5 and 0.7. The optimisation is on the 1D projection index, $I^{nk}(n)$, for \\code{boa6} data, where a local optimum, annotated by the cross (x), is presented in this experiment, along with the global optimum (*)."----


## ----flip-sign, fig.cap = "Comparison of the interpolation in the PCA-projected basis space before and after reconciling the orientation of the target basis. Optimisation is on the 1D projection index, $I^{nk}(n)$, for boa6 data using CRS with seed 2463. The dots represent the target basis in each iteration, and the path shows the interpolation. On the left panel, one target basis is generated with an opposite orientation to the current basis (hence appear on the other side of the basis space), and the interpolator crosses the origin to perform the interpolation. The right panel shows the same interpolation after implementing an orientation check, and the undesirable interpolation disappears."----

